@@ -605,35 +605,39 @@ def GraEstModels(a,b,c,d,e,f,g,h):
     fig, axs = plt.subplots(nrows=1, ncols=4, figsize=(24, 6))
     axs[0].scatter(a,b,color="#008080");
     axs[0].plot(red,red,color="red")
-    axs[0].set_xlabel('Valor Observado')
-    axs[0].set_ylabel('Valor Estimado')
+    axs[0].set_xlabel('Valor Observado',size=14)
+    axs[0].set_ylabel('Valor Estimado',size=14)
     axs[0].grid(True)
     axs[0].set_xlim(xmin,xmax)
     axs[0].set_ylim(ymin,ymax)
+    axs[0].set_title('Regresión Lineal', size= 18)
 
     axs[1].scatter(c,d,color="#008080");
     axs[1].plot(red,red,color="red")
-    axs[1].set_xlabel('Valor Observado')
-    axs[1].set_ylabel('Valor Estimado')
+    axs[1].set_xlabel('Valor Observado',size=14)
+    axs[1].set_ylabel('Valor Estimado',size=14)
     axs[1].grid(True)
     axs[1].set_xlim(xmin,xmax)
     axs[1].set_ylim(ymin,ymax)
+    axs[1].set_title('ElasticNet', size= 18)
     
     axs[2].scatter(e,f,color="#008080");
     axs[2].plot(red,red,color="red")
-    axs[2].set_xlabel('Valor Observado')
-    axs[2].set_ylabel('Valor Estimado')
+    axs[2].set_xlabel('Valor Observado',size=14)
+    axs[2].set_ylabel('Valor Estimado',size=14)
     axs[2].grid(True)
     axs[2].set_xlim(xmin,xmax)
     axs[2].set_ylim(ymin,ymax)
+    axs[2].set_title('Random Forest', size= 18)
     
     axs[3].scatter(g,h,color="#008080");
     axs[3].plot(red,red,color="red")
-    axs[3].set_xlabel('Valor Observado')
-    axs[3].set_ylabel('Valor Estimado')
+    axs[3].set_xlabel('Valor Observado',size=14)
+    axs[3].set_ylabel('Valor Estimado',size=14)
     axs[3].grid(True)
     axs[3].set_xlim(xmin,xmax)
     axs[3].set_ylim(ymin,ymax)
+    axs[3].set_title('Xtrem Gradient Boosting', size= 18)
 
     plt.tight_layout();
 
